pecos.engines.cvm.sim\_func
===========================

.. automodule:: pecos.engines.cvm.sim_func







   .. rubric:: Functions

   .. autosummary::

      sim_exec
      sim_get_amp
      sim_get_amps
      sim_noise
      sim_noise_off
      sim_noise_on
      sim_print
      sim_test
